########
 setux
########

**Setux Plus**

Augmented Setux Distribution

========
Abstract
========

Extra Setux Packages implementation.

=====
Usage
=====

REPL:
.. code-block:: shell

    setux

Python:
.. code-block:: python

   import setux

============
Installation
============

.. code-block:: shell 

    $ pip install setux_plus
